#!/bin/sh -

# Halt on first error and show what's happening

set -ex

# Start rpkid so we can configure it, make sure we shut it down on exit
# If we're running under screen, just run it in a different screen instead.

if test -n "$STY"
then
  screen python rpkid.py
else
  python rpkid.py >>rpkid.log 2>&1 & rpkid=$!
  trap "kill $rpkid" 0 1 2 3 13 15
fi

sleep 15

# Need to cross-certify:
# 
#   APNIC-CMS-CERT   into ISC-SELF-1's BPKI (ISC-SELF-1-APNIC-CMS-CERT.cer)
#   APNIC-HTTPS-CERT into ISC-SELF-1's BPKI (ISC-SELF-1-APNIC-HTTPS-CERT.cer)

certifier=ISC-SELF-1
for certificant in APNIC-CMS-CERT APNIC-HTTPS-CERT
do
  python cross-certify.py				\
      -i	"$certificant.cer"			\
      -o	"$certifier-$certificant.cer"		\
      -c	"$certifier.cer"			\
      -k	"$certifier.key"			\
      -s	"$certifier.srl"
done

# Both of the cross certified things we just generated go into the
# parent object we need to create below.

# I should have done something about installing the BSC signing_cert here

python irbe-cli.py repository --self_id 1 --action create --bsc_id 1

python irbe-cli.py parent --self_id 1 --action create --bsc_id 1 --repository_id 1 \
    --peer_contact_uri	https://rosella.apnic.net/cgi-bin/up-down-cms.cgi	\
    --bpki_cms_cert	ISC-SELF-1-APNIC-CMS-CERT.cer				\
    --bpki_https_cert	ISC-SELF-1-APNIC-HTTPS-CERT.cer				\
    --sia_base		rsync://wombat.invalid/					\
    --recipient_name	APNIC-AP						\
    --sender_name	A915B536

# Run the other daemons, arrange for everything to go away on shutdown,
# run initial cron job to set things up, then wait

if test -n "$STY"
then
  screen python irdbd.py
else
  python irdbd.py >>irdbd.log 2>&1 & irdbd=$!
  trap "kill $rpkid $irdbd" 0 1 2 3 13 15
fi

python cronjob.py

if test -z "$STY"
then
  tail +0f rpkid.log
fi
